from a10sdk.common.A10BaseClass import A10BaseClass


class AclNameList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_name: {"description": "Apply an access list name (Named Access List)", "format": "string", "minLength": 1, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}
    :param acl_name_src_nat_pool: {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param acl_name_seq_num: {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-name-list"
        self.DeviceProxy = ""
        self.acl_name = ""
        self.acl_name_src_nat_pool = ""
        self.acl_name_seq_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AflexScripts(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param aflex: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Bind aFleX Script to the Virtual Port (aFleX Script Name)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "aflex-scripts"
        self.DeviceProxy = ""
        self.aflex = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AclIdList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_id_seq_num: {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}
    :param acl_id: {"description": "ACL id VPORT", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param acl_id_src_nat_pool: {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-id-list"
        self.DeviceProxy = ""
        self.acl_id_seq_num = ""
        self.acl_id = ""
        self.acl_id_src_nat_pool = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AuthCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param aaa_policy: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify AAA policy name to bind to the virtual port", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "auth-cfg"
        self.DeviceProxy = ""
        self.aaa_policy = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Virtual Port.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param reset_on_server_selection_fail: {"default": 0, "optional": true, "type": "number", "description": "Send client reset when server selection fails", "format": "flag"}
    :param ha_conn_mirror: {"default": 0, "optional": true, "type": "number", "description": "Enable for HA Conn sync", "format": "flag"}
    :param template_ftp: {"description": "FTP port template (Ftp template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/slb/template/ftp"}
    :param protocol: {"optional": false, "enum": ["tcp", "udp", "others", "diameter", "dns-tcp", "dns-udp", "fast-http", "fix", "ftp", "ftp-proxy", "http", "https", "mlb", "mms", "mysql", "mssql", "radius", "rtsp", "sip", "sip-tcp", "sips", "smpp-tcp", "spdy", "spdys", "smtp", "ssl-proxy", "tcp-proxy", "tftp"], "type": "string", "description": "'tcp': TCP LB service; 'udp': UDP Port; 'others': for no tcp/udp protocol, do IP load balancing; 'diameter': diameter port; 'dns-tcp': DNS service over TCP; 'dns-udp': DNS service over UDP; 'fast-http': Fast HTTP Port; 'fix': FIX Port; 'ftp': File Transfer Protocol Port; 'ftp-proxy': ftp proxy port; 'http': HTTP Port; 'https': HTTPS port; 'mlb': Message based load balancing; 'mms': Microsoft Multimedia Service Port; 'mysql': mssql port; 'mssql': mssql; 'radius': Radius Port; 'rtsp': Real Time Streaming Protocol Port; 'sip': Session initiation protocol over UDP; 'sip-tcp': Session initiation protocol over TCP; 'sips': Session initiation protocol over TLS; 'smpp-tcp': SMPP service over TCP; 'spdy': spdy port; 'spdys': spdys port; 'smtp': SMTP Port; 'ssl-proxy': Generic SSL proxy; 'tcp-proxy': Generic TCP proxy; 'tftp': TFTP Port; ", "format": "enum"}
    :param force_routing_mode: {"default": 0, "optional": true, "type": "number", "description": "Force routing mode", "format": "flag"}
    :param waf_template: {"description": "WAF template (WAF Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}
    :param l7_hardware_assist: {"description": "FPGA assist L7 packet parsing", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}
    :param template_persist_ssl_sid: {"description": "SSL session ID persistence (Source IP Persistence Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/ssl-sid"}
    :param no_auto_up_on_aflex: {"default": 0, "optional": true, "type": "number", "description": "Don't automatically mark vport up when aFleX is bound", "format": "flag"}
    :param template_dns: {"description": "DNS template (DNS template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/dns"}
    :param template_http_policy: {"description": "http-policy template (http-policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/http-policy"}
    :param gslb_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Global Server Load Balancing", "format": "flag"}
    :param template_policy: {"description": "Policy Template (Policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}
    :param use_alternate_port: {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port", "format": "flag"}
    :param ipinip: {"default": 0, "optional": true, "type": "number", "description": "Enable IP in IP", "format": "flag"}
    :param acl_name_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-name": {"description": "Apply an access list name (Named Access List)", "format": "string", "minLength": 1, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}, "acl-name-src-nat-pool": {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}, "optional": true, "acl-name-seq-num": {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}}}]}
    :param stats_data_action: {"description": "'stats-data-enable': Enable statistical data collection for virtual port; 'stats-data-disable': Disable statistical data collection for virtual port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}
    :param template_persist_destination_ip: {"description": "Destination IP persistence (Destination IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/destination-ip"}
    :param template_tcp_proxy_server: {"description": "TCP Proxy Config Server (TCP Proxy Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}
    :param template_sip: {"description": "SIP template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/sip"}
    :param template_virtual_port: {"description": "Virtual port template (Virtual port template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/virtual-port"}
    :param conn_limit: {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}
    :param precedence: {"default": 0, "optional": true, "type": "number", "description": "Set auto NAT pool as higher precedence for source NAT", "format": "flag"}
    :param template_client_ssl: {"description": "Client SSL Template (Client SSL Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/client-ssl"}
    :param template_persist_cookie: {"description": "Cookie persistence (Cookie persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/cookie"}
    :param template_tcp: {"description": "L4 TCP Template (TCP Config Name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp"}
    :param template_tcp_proxy_client: {"description": "TCP Proxy Config Client (TCP Proxy Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}
    :param template_connection_reuse: {"description": "Connection Reuse Template (Connection Reuse Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/connection-reuse"}
    :param service_group: {"description": "Bind a Service Group to this Virtual Server (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param pool: {"description": "Specify NAT pool or pool group", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param persist_type: {"optional": true, "enum": ["src-dst-ip-swap-persist", "use-src-ip-for-dst-persist", "use-dst-ip-for-src-persist"], "type": "string", "description": "'src-dst-ip-swap-persist': Create persist session after source IP and destination IP swap; 'use-src-ip-for-dst-persist': Use the source IP to create a destination persist session; 'use-dst-ip-for-src-persist': Use the destination IP to create source IP persist session; ", "format": "enum"}
    :param template_fix: {"description": "FIX template (FIX Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/fix"}
    :param snat_on_vip: {"default": 0, "optional": true, "type": "number", "description": "Enable source NAT traffic against VIP", "format": "flag"}
    :param bucket_count: {"optional": true, "minimum": 1, "type": "number", "maximum": 256, "format": "number"}
    :param use_default_if_no_server: {"default": 0, "optional": true, "type": "number", "description": "Use default forwarding if server selection failed", "format": "flag"}
    :param syn_cookie: {"default": 0, "optional": true, "type": "number", "description": "Enable syn-cookie", "format": "flag"}
    :param when_down: {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when down", "format": "flag"}
    :param template_udp: {"description": "L4 UDP Template (UDP Config Name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/udp"}
    :param aflex_scripts: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"aflex": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Bind aFleX Script to the Virtual Port (aFleX Script Name)", "format": "string"}, "optional": true}}]}
    :param acl_id_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-id-seq-num": {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}, "acl-id": {"description": "ACL id VPORT", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}, "optional": true, "acl-id-src-nat-pool": {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}}}]}
    :param alternate_port: {"description": "Alternate Virtual Port", "format": "flag", "default": 0, "optional": true, "modify-not-allowed": 1, "not": "range", "type": "number"}
    :param auto: {"default": 0, "optional": true, "type": "number", "description": "Configure auto NAT for the vport", "format": "flag"}
    :param view: {"description": "Specify a GSLB View (ID)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param alternate_port_number: {"description": "Virtual Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": true}
    :param port_number: {"description": "Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}
    :param device_group: {"optional": true, "minimum": 1, "type": "number", "maximum": 64, "format": "number"}
    :param use_rcv_hop_for_resp: {"default": 0, "optional": true, "type": "number", "description": "Use receive hop for response to client", "format": "flag"}
    :param no_dest_nat: {"default": 0, "optional": true, "type": "number", "description": "Disable destination NAT", "format": "flag"}
    :param template_external_service: {"description": "External service template (external-service template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/external-service"}
    :param template_cache: {"description": "RAM caching template (Cache Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/cache"}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on virtual port", "format": "flag"}
    :param expand: {"default": 0, "optional": true, "type": "number", "description": "expand syn-cookie with timestamp and wscale", "format": "flag"}
    :param reset: {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection number over limit", "format": "flag"}
    :param req_fail: {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when L7 request fail", "format": "flag"}
    :param skip_rev_hash: {"default": 0, "optional": true, "type": "number", "description": "Skip rev tuple hash insertion", "format": "flag"}
    :param name: {"description": "SLB Virtual Service Name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param template_dblb: {"description": "DBLB Template (DBLB template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/dblb"}
    :param port_translation: {"default": 0, "optional": true, "type": "number", "description": "Enable port translation under no-dest-nat", "format": "flag"}
    :param template_smpp: {"description": "SMPP template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/smpp"}
    :param clientip_sticky_nat: {"default": 0, "optional": true, "type": "number", "description": "Prefer to use same source NAT address for a client", "format": "flag"}
    :param template_persist_source_ip: {"description": "Source IP persistence (Source IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/source-ip"}
    :param serv_sel_fail: {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when server selection failure", "format": "flag"}
    :param template_diameter: {"description": "Diameter Template (diameter template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/diameter"}
    :param range: {"description": "Virtual Port range (Virtual Port range value)", "format": "number", "default": 0, "optional": true, "maximum": 254, "minimum": 0, "modify-not-allowed": 1, "not": "alternate-port", "type": "number"}
    :param when_down_protocol2: {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when down", "format": "flag"}
    :param def_selection_if_pref_failed: {"description": "'def-selection-if-pref-failed': Use default server selection method if prefer method failed; 'def-selection-if-pref-failed-disable': Stop using default server selection method if prefer method failed; ", "format": "enum", "default": "def-selection-if-pref-failed", "type": "string", "enum": ["def-selection-if-pref-failed", "def-selection-if-pref-failed-disable"], "optional": true}
    :param template_tcp_proxy: {"description": "TCP Proxy Template Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}
    :param template_smtp: {"description": "SMTP Template (SMTP Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/smtp"}
    :param action: {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param template_http: {"description": "HTTP Template (HTTP Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/http"}
    :param no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param template_server_ssl: {"description": "Server Side SSL Template (Server SSL Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server-ssl"}
    :param alt_protocol2: {"optional": true, "enum": ["tcp"], "type": "string", "description": "'tcp': TCP LB service; ", "format": "enum"}
    :param alt_protocol1: {"optional": true, "enum": ["http"], "type": "string", "description": "'http': HTTP Port; ", "format": "enum"}
    :param message_switching: {"default": 0, "optional": true, "type": "number", "description": "Message switching", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/virtual-server/{name}/port/{port_number}+{protocol}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/slb/virtual-server/{name}/port/{port_number}+{protocol}"
        self.DeviceProxy = ""
        self.reset_on_server_selection_fail = ""
        self.ha_conn_mirror = ""
        self.template_ftp = ""
        self.protocol = ""
        self.force_routing_mode = ""
        self.waf_template = ""
        self.l7_hardware_assist = ""
        self.template_persist_ssl_sid = ""
        self.no_auto_up_on_aflex = ""
        self.template_dns = ""
        self.template_http_policy = ""
        self.gslb_enable = ""
        self.template_policy = ""
        self.use_alternate_port = ""
        self.ipinip = ""
        self.acl_name_list = []
        self.stats_data_action = ""
        self.template_persist_destination_ip = ""
        self.template_tcp_proxy_server = ""
        self.template_sip = ""
        self.template_virtual_port = ""
        self.conn_limit = ""
        self.precedence = ""
        self.template_client_ssl = ""
        self.template_persist_cookie = ""
        self.template_tcp = ""
        self.template_tcp_proxy_client = ""
        self.template_connection_reuse = ""
        self.service_group = ""
        self.pool = ""
        self.persist_type = ""
        self.template_fix = ""
        self.snat_on_vip = ""
        self.bucket_count = ""
        self.use_default_if_no_server = ""
        self.syn_cookie = ""
        self.when_down = ""
        self.template_udp = ""
        self.aflex_scripts = []
        self.acl_id_list = []
        self.alternate_port = ""
        self.auto = ""
        self.view = ""
        self.alternate_port_number = ""
        self.port_number = ""
        self.device_group = ""
        self.use_rcv_hop_for_resp = ""
        self.no_dest_nat = ""
        self.template_external_service = ""
        self.template_cache = ""
        self.extended_stats = ""
        self.expand = ""
        self.reset = ""
        self.req_fail = ""
        self.skip_rev_hash = ""
        self.name = ""
        self.template_dblb = ""
        self.port_translation = ""
        self.template_smpp = ""
        self.clientip_sticky_nat = ""
        self.template_persist_source_ip = ""
        self.serv_sel_fail = ""
        self.template_diameter = ""
        self.A10WW_range = ""
        self.when_down_protocol2 = ""
        self.def_selection_if_pref_failed = ""
        self.template_tcp_proxy = ""
        self.template_smtp = ""
        self.auth_cfg = {}
        self.action = ""
        self.template_http = ""
        self.no_logging = ""
        self.template_server_ssl = ""
        self.alt_protocol2 = ""
        self.alt_protocol1 = ""
        self.message_switching = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param server_selection_fail_drop: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param server_selection_fail_reset: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param service_peak_conn: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.server_selection_fail_drop = ""
        self.server_selection_fail_reset = ""
        self.service_peak_conn = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceGroup(A10BaseClass):
    
    """Class Description::
    Statistics for the object service-group.

    Class service-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param member_list: {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"stats": {"type": "object", "properties": {"curr_req": {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}, "total_fwd_bytes": {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}, "peak_conn": {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}, "total_req": {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}, "total_conn": {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}, "fastest_rsp_time": {"optional": true, "size": "8", "type": "number", "oid": "15", "format": "counter"}, "total_fwd_pkts": {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}, "total_rev_pkts_inspected_status_code_non_5xx": {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}, "total_rev_pkts": {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}, "total_rev_pkts_inspected_status_code_2xx": {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}, "total_req_succ": {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}, "curr_conn": {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}, "total_rev_pkts_inspected": {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}, "total_rev_bytes": {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}, "slowest_rsp_time": {"optional": true, "size": "8", "type": "number", "oid": "16", "format": "counter"}, "response_time": {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}}}, "name": {"description": "Member name", "format": "comp-string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "oid": "1002", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/service-group/{name}/member/{name}+{port}"}
    :param name: {"description": "CGNV6 Service Name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/service-group/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "service-group"
        self.a10_url="/axapi/v3/cgnv6/service-group/{name}/stats"
        self.DeviceProxy = ""
        self.member_list = []
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DeviceGroup(A10BaseClass):
    
    """Class Description::
    configure scaleout device groups.

    Class device-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param device_group: {"description": "scaletout device group", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}
    :param device_id_start: {"optional": true, "type": "number", "format": "number"}
    :param device_id_end: {"optional": true, "type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/acos-scaleout/cluster-config/device-groups/device-group/{device_group}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "device_group"]

        self.b_key = "device-group"
        self.a10_url="/axapi/v3/acos-scaleout/cluster-config/device-groups/device-group/{device_group}"
        self.DeviceProxy = ""
        self.device_group = ""
        self.device_id_start = ""
        self.device_id_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class StatefulFirewall(A10BaseClass):
    
    """Class Description::
    Configure Stateful Firewall direction.

    Class stateful-firewall supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param access_list: {"default": 0, "optional": true, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}
    :param inside: {"default": 0, "optional": true, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}
    :param acl_id: {"description": "ACL id", "format": "number", "type": "number", "maximum": 199, "minimum": 1, "optional": true}
    :param outside: {"default": 0, "optional": true, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ve/{ifnum}/ip/stateful-firewall`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "stateful-firewall"
        self.a10_url="/axapi/v3/interface/ve/{ifnum}/ip/stateful-firewall"
        self.DeviceProxy = ""
        self.access_list = ""
        self.inside = ""
        self.acl_id = ""
        self.outside = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Monitor(A10BaseClass):
    
    """Class Description::
    Configure NetFlow Monitor.

    Class monitor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param source_ip_use_mgmt: {"default": 0, "optional": true, "type": "number", "description": "Use management interface's IP address for source ip of netflow packets", "format": "flag"}
    :param protocol: {"description": "'v9': Netflow version 9; 'v10': Netflow version 10 (IPFIX); ", "format": "enum", "default": "v9", "type": "string", "enum": ["v9", "v10"], "optional": true}
    :param name: {"description": "Name of netflow monitor", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable this netflow monitor", "format": "flag"}
    :param flow_timeout: {"description": "Configure timeout value to export flow records periodically for long-live session ( Number of minutes: default is 10, 0 means only send flow record when session is deleted)", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "monitor"
        self.a10_url="/axapi/v3/netflow/monitor/{name}"
        self.DeviceProxy = ""
        self.source_ip_use_mgmt = ""
        self.protocol = ""
        self.name = ""
        self.source_address = {}
        self.destination = {}
        self.sample = {}
        self.record = {}
        self.disable = ""
        self.resend_template = {}
        self.flow_timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"not-list": ["service-group", "ipv6"], "type": "string", "description": "IP address of netflow collector", "format": "ipv4-address"}
    :param port4: {"description": "Port number, default is 9996", "format": "number", "default": 9996, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-cfg"
        self.DeviceProxy = ""
        self.ip = ""
        self.port4 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6Cfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port6: {"description": "Port number, default is 9996", "format": "number", "default": 9996, "maximum": 65535, "minimum": 1, "type": "number"}
    :param ipv6: {"not-list": ["service-group", "ip"], "type": "string", "description": "IPv6 address of netflow collector", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-cfg"
        self.DeviceProxy = ""
        self.port6 = ""
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Destination(A10BaseClass):
    
    """Class Description::
    Configure destination where netflow records will be sent.

    Class destination supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param service_group: {"description": "Service-group for load balancing between multiple collector servers", "format": "string-rlx", "minLength": 1, "not-list": ["ip", "ipv6"], "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}/destination`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "destination"
        self.a10_url="/axapi/v3/netflow/monitor/{name}/destination"
        self.DeviceProxy = ""
        self.ip_cfg = {}
        self.service_group = ""
        self.ipv6_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Devicelist(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param device_id: {"description": "scaletout device id", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param ip: {"type": "string", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "deviceList"
        self.DeviceProxy = ""
        self.device_id = ""
        self.ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClusterDevices(A10BaseClass):
    
    """Class Description::
    Configure devices in the cluster.

    Class cluster-devices supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param deviceList: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"device-id": {"description": "scaletout device id", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "ip": {"type": "string", "format": "ipv4-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/acos-scaleout/cluster-config/cluster-devices`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "cluster-devices"
        self.a10_url="/axapi/v3/acos-scaleout/cluster-config/cluster-devices"
        self.DeviceProxy = ""
        self.deviceList = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Export(A10BaseClass):
    
    """    :param geo_location: {"description": "Geo-location CSV File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param ssl_cert_key: {"description": "Local SSL Key/Certificate file name", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param bw_list: {"description": "Black white List File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param merged_pcap: {"default": 0, "optional": true, "type": "number", "description": "Export the merged pcap file when there are multiple Export sessions", "format": "flag"}
    :param syslog: {"description": "Syslog file", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param auth_portal: {"description": "Portal file for http authentication", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param aflex: {"description": "aFleX Script Source File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param fixed_nat: {"description": "Fixed NAT Port Mapping File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param saml_idp_name: {"description": "SAML metadata of identity provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param class_list: {"description": "Class List File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param debug_monitor: {"description": "Debug Monitor Output", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param policy: {"description": "WAF policy File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param running_config: {"default": 0, "optional": true, "type": "number", "description": "Running Config", "format": "flag"}
    :param auth_portal_image: {"description": "Image file for default portal", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param ssl_crl: {"description": "SSL Crl File", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param remote_file: {"not": "store-name", "optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param dnssec_ds: {"description": "DNSSEC DS file for child zone", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param profile: {"description": "Startup-config Profile", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param local_uri_file: {"description": "Local URI files for http response", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param wsdl: {"description": "Web Services Definition Language File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param ssl_key: {"description": "SSL Key File(enter bulk when import an archive file)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param externalfilename: {"description": "Export the External Program from the System", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param store_name: {"description": "Export store name", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "remote-file", "type": "string"}
    :param axdebug: {"description": "AX Debug Packet File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param lw_4o6: {"description": "LW-4over6 Binding Table File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param xml_schema: {"description": "XML-Schema File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param startup_config: {"default": 0, "optional": true, "type": "number", "description": "Startup Config", "format": "flag"}
    :param ssl_cert: {"description": "SSL Cert File(enter bulk when import an archive file)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param dnssec_dnskey: {"description": "DNSSEC DNSKEY(KSK) file for child zone", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Put files to remote site.

    Class export supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/export`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "export"
        self.a10_url="/axapi/v3/export"
        self.DeviceProxy = ""
        self.geo_location = ""
        self.ssl_cert_key = ""
        self.bw_list = ""
        self.merged_pcap = ""
        self.syslog = ""
        self.auth_portal = ""
        self.aflex = ""
        self.fixed_nat = ""
        self.saml_idp_name = ""
        self.class_list = ""
        self.debug_monitor = ""
        self.policy = ""
        self.running_config = ""
        self.auth_portal_image = ""
        self.ssl_crl = ""
        self.remote_file = ""
        self.dnssec_ds = ""
        self.profile = ""
        self.local_uri_file = ""
        self.wsdl = ""
        self.ssl_key = ""
        self.store = {}
        self.externalfilename = ""
        self.use_mgmt_port = ""
        self.store_name = ""
        self.axdebug = ""
        self.lw_4o6 = ""
        self.xml_schema = ""
        self.startup_config = ""
        self.ssl_cert = ""
        self.dnssec_dnskey = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AclNameList(A10BaseClass):
    
    """Class Description::
    Apply an access list.

    Class acl-name-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param msl: {"description": "Maximum Session Life Value", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}
    :param name: {"description": "Apply an access list", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}
    :param pool: {"description": "Pool or Pool Group (Pool or Pool Group Nam)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/inside/source/list/acl-name-list/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "acl-name-list"
        self.a10_url="/axapi/v3/ip/nat/inside/source/list/acl-name-list/{name}"
        self.DeviceProxy = ""
        self.msl = ""
        self.name = ""
        self.pool = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeoLocationClassList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param filename: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify file to be deleted", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geo-location-class-list"
        self.DeviceProxy = ""
        self.filename = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BwList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param file_name: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Blacklist/whitelist Name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bw-list"
        self.DeviceProxy = ""
        self.file_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Delete(A10BaseClass):
    
    """Class Description::
    Delete Configuration file.

    Class delete supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/delete`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "delete"
        self.a10_url="/axapi/v3/delete"
        self.DeviceProxy = ""
        self.health_postfile = {}
        self.geo_location_class_list = {}
        self.bw_list = {}
        self.geo_location = {}
        self.auth_portal_image = {}
        self.partition = {}
        self.debug_monitor = {}
        self.health_external = {}
        self.auth_portal = {}
        self.startup_config = {}
        self.local_uri_file = {}
        self.auth_saml_idp = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DestinationIpAddress(A10BaseClass):
    
    """Class Description::
    Configure remote tunnel end point parameters.

    Class destination-ip-address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vni_list: {"minItems": 1, "items": {"type": "vni"}, "uniqueItems": true, "array": [{"required": ["segment"], "properties": {"segment": {"description": "VNI configured for the remote VTEP", "format": "number", "type": "number", "maximum": 16777215, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}/destination-ip-address/{ip-address}/vni/{segment}"}
    :param encap: {"optional": true, "enum": ["nvgre", "vxlan"], "type": "string", "description": "'nvgre': Tunnel Encapsulation Type is NVGRE; 'vxlan': Tunnel Encapsulation Type is NVGRE; ", "format": "enum"}
    :param ip_address: {"optional": false, "type": "string", "description": "IP Address of the remote VTEP", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/overlay-tunnel/vtep/{id}/destination-ip-address/{ip_address}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_address"]

        self.b_key = "destination-ip-address"
        self.a10_url="/axapi/v3/overlay-tunnel/vtep/{id}/destination-ip-address/{ip_address}"
        self.DeviceProxy = ""
        self.vni_list = []
        self.encap = ""
        self.ip_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PacketsPerSecond(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"description": "Configure packets-per-second threshold per IP(default 3000)", "format": "number", "default": 3000, "maximum": 30000000, "minimum": 0, "type": "number"}
    :param udp: {"description": "Configure packets-per-second threshold per UDP port (default: 3000)", "format": "number", "default": 3000, "maximum": 30000000, "minimum": 0, "type": "number"}
    :param other: {"description": "Configure packets-per-second threshold for other L4 protocols(default 10000)", "format": "number", "default": 10000, "maximum": 30000000, "minimum": 0, "type": "number"}
    :param tcp: {"description": "Configure packets-per-second threshold per TCP port (default: 3000)", "format": "number", "default": 3000, "maximum": 30000000, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "packets-per-second"
        self.DeviceProxy = ""
        self.ip = ""
        self.udp = ""
        self.other = ""
        self.tcp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Logging(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param logging_toggle: {"default": "enable", "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable CGNV6 NAT pool DDoS protection logging (default); 'disable': Disable CGNV6 NAT pool DDoS protection logging; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "logging"
        self.DeviceProxy = ""
        self.logging_toggle = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DdosProtection(A10BaseClass):
    
    """Class Description::
    Configure CGNV6 DDoS Protection.

    Class ddos-protection supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param toggle: {"description": "'enable': Enable CGNV6 NAT pool DDoS protection (default); 'disable': Disable CGNV6 NAT pool DDoS protection; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/ddos-protection`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ddos-protection"
        self.a10_url="/axapi/v3/cgnv6/ddos-protection"
        self.DeviceProxy = ""
        self.packets_per_second = {}
        self.toggle = ""
        self.logging = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Template(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dnssec: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify DNSSEC template (Specify template name)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "template"
        self.DeviceProxy = ""
        self.dnssec = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsSoaRecord(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param retry: {"default": 900, "type": "number", "description": "Specify Retry Time Interval, default is 900", "format": "number"}
    :param soa_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "DNS Server Name", "format": "string"}
    :param ex_retry: {"default": 900, "type": "number", "description": "Specify Retry Time Interval, default is 900", "format": "number"}
    :param ex_soa_ttl: {"type": "number", "description": "Specify Negative caching TTL, default is Zone TTL", "format": "number"}
    :param ex_serial: {"type": "number", "description": "Specify Serial Number, default is Current Time (Time Interval)", "format": "number"}
    :param refresh: {"default": 3600, "type": "number", "description": "Specify Refresh Time Interval, default is 3600", "format": "number"}
    :param ex_mail: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Mailbox", "format": "string"}
    :param expire: {"default": 1209600, "type": "number", "description": "Specify Expire Time Interval, default is 1209600", "format": "number"}
    :param ex_expire: {"default": 1209600, "type": "number", "description": "Specify Expire Time Interval, default is 1209600", "format": "number"}
    :param external: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify External SOA Record (DNS Server Name)", "format": "string"}
    :param mail: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Mailbox", "format": "string"}
    :param serial: {"type": "number", "description": "Specify Serial Number, default is Current Time (Time Interval)", "format": "number"}
    :param ex_refresh: {"default": 3600, "type": "number", "description": "Specify Refresh Time Interval, default is 3600", "format": "number"}
    :param soa_ttl: {"type": "number", "description": "Specify Negative caching TTL, default is Zone TTL", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns-soa-record"
        self.DeviceProxy = ""
        self.retry = ""
        self.soa_name = ""
        self.ex_retry = ""
        self.ex_soa_ttl = ""
        self.ex_serial = ""
        self.refresh = ""
        self.ex_mail = ""
        self.expire = ""
        self.ex_expire = ""
        self.external = ""
        self.mail = ""
        self.serial = ""
        self.ex_refresh = ""
        self.soa_ttl = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Zone(A10BaseClass):
    
    """Class Description::
    Specify the DNS zone name for which global SLB is provided.

    Class zone supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify the name for the DNS zone", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param dns_ns_record_list: {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-ns-record/{ns-name}"}
    :param dns_mx_record_list: {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"priority": {"description": "Specify Priority", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}"}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable all services in the GSLB zone", "format": "flag"}
    :param ttl: {"description": "Specify the zone ttl value (TTL value, unit: second, default is 10)", "format": "number", "default": 10, "optional": true, "maximum": 1000000000, "minimum": 0, "not": "use-server-ttl", "type": "number"}
    :param policy: {"description": "Specify the policy for this zone (Specify policy name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param use_server_ttl: {"description": "Use DNS Server Response TTL value in GSLB Proxy mode", "format": "flag", "default": 0, "optional": true, "not": "ttl", "type": "number"}
    :param service_list: {"minItems": 1, "items": {"type": "service"}, "uniqueItems": true, "array": [{"required": ["service-port", "service-name"], "properties": {"dns-a-record": {"type": "object", "properties": {"dns-a-record-ipv6-list": {"minItems": 1, "items": {"type": "dns-a-record-ipv6"}, "uniqueItems": true, "array": [{"required": ["dns-a-record-ipv6"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "dns-a-record-ipv6": {"optional": false, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-ipv6/{dns-a-record-ipv6}"}, "dns-a-record-ipv4-list": {"minItems": 1, "items": {"type": "dns-a-record-ipv4"}, "uniqueItems": true, "array": [{"required": ["dns-a-record-ip"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "dns-a-record-ip": {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-ipv4/{dns-a-record-ip}"}, "dns-a-record-srv-list": {"minItems": 1, "items": {"type": "dns-a-record-srv"}, "uniqueItems": true, "array": [{"required": ["svrname"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "svrname": {"description": "Specify name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/service-ip"}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-srv/{svrname}"}}}, "forward-type": {"optional": true, "enum": ["both", "query", "response"], "type": "string", "description": "'both': Forward both query and response; 'query': Forward query; 'response': Forward response; ", "format": "enum"}, "dns-cname-record-list": {"minItems": 1, "items": {"type": "dns-cname-record"}, "uniqueItems": true, "array": [{"required": ["alias-name"], "properties": {"as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "alias-name": {"description": "Specify the alias name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "admin-preference": {"description": "Specify Administrative Preference, default is 100", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "weight": {"description": "Specify Weight, default is 1", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-cname-record/{alias-name}"}, "health-check-port": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "health-check-port": {"description": "Check Related Port Status (Port Number)", "minimum": 0, "type": "number", "maximum": 65534, "format": "number"}}}]}, "policy": {"description": "Specify policy for this service (Specify policy name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "dns-txt-record-list": {"minItems": 1, "items": {"type": "dns-txt-record"}, "uniqueItems": true, "array": [{"required": ["record-name"], "properties": {"record-name": {"description": "Specify the Object Name for TXT Data", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "txt-data": {"description": "Specify TXT Data", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 1000, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-txt-record/{record-name}"}, "service-port": {"description": "Port number of the service", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "dns-mx-record-list": {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"priority": {"description": "Specify Priority", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-mx-record/{mx-name}"}, "dns-record-list": {"minItems": 1, "items": {"type": "dns-record"}, "uniqueItems": true, "array": [{"required": ["type"], "properties": {"data": {"description": "Specify DNS Data", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 512, "type": "string"}, "type": {"description": "Specify DNS Type", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-record/{type}"}, "dns-ns-record-list": {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-ns-record/{ns-name}"}, "health-check-gateway": {"description": "'enable': Enable Gateway Status Check; 'disable': Disable Gateway Status Check; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable", "format": "flag"}, "dns-srv-record-list": {"minItems": 1, "items": {"type": "dns-srv-record"}, "uniqueItems": true, "array": [{"required": ["srv-name", "port"], "properties": {"priority": {"description": "Specify Priority", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "srv-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "port": {"description": "Specify Port (Port Number)", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "weight": {"description": "Specify Weight, default is 10", "format": "number", "default": 10, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-srv-record/{srv-name}+{port}"}, "service-name": {"description": "Specify the service name for the zone, * for wildcard", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "action": {"optional": true, "enum": ["drop", "forward", "ignore", "reject"], "type": "string", "description": "'drop': Drop query; 'forward': Forward packet; 'ignore': Send empty response; 'reject': Send refuse response; ", "format": "enum"}, "dns-ptr-record-list": {"minItems": 1, "items": {"type": "dns-ptr-record"}, "uniqueItems": true, "array": [{"required": ["ptr-name"], "properties": {"ptr-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-ptr-record/{ptr-name}"}, "geo-location-list": {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["geo-name"], "properties": {"forward-type": {"optional": true, "enum": ["both", "query", "response"], "type": "string", "description": "'both': Forward both query and response; 'query': Forward query from this geo-location; 'response': Forward response to this geo-location; ", "format": "enum"}, "alias": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alias": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Send CNAME response for this geo-location (Specify a CNAME record)", "format": "string"}, "optional": true}}]}, "action-type": {"optional": true, "enum": ["allow", "drop", "forward", "ignore", "reject"], "type": "string", "description": "'allow': Allow query from this geo-location; 'drop': Drop query from this geo-location; 'forward': Forward packet for this geo-location; 'ignore': Send empty response to this geo-location; 'reject': Send refuse response to this geo-location; ", "format": "enum"}, "policy": {"description": "Policy for this geo-location (Specify the policy name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "action", "type": "string"}, "action": {"description": "Action for this geo-location", "format": "flag", "default": 0, "optional": true, "not": "policy", "type": "number"}, "geo-name": {"description": "Specify the geo-location", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/geo-location/{geo-name}"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "zone"
        self.a10_url="/axapi/v3/gslb/zone/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.dns_ns_record_list = []
        self.dns_mx_record_list = []
        self.disable = ""
        self.template = {}
        self.ttl = ""
        self.policy = ""
        self.use_server_ttl = ""
        self.dns_soa_record = {}
        self.service_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MapCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map name", "format": "string"}
    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param route_map_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Route map set for input filtering; 'out': Route map set for output filtering; ", "format": "enum"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "map-cfg"
        self.DeviceProxy = ""
        self.A10WW_map = ""
        self.ve = ""
        self.loopback = ""
        self.route_map_direction = ""
        self.trunk = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RouteMap(A10BaseClass):
    
    """Class Description::
    Route map set.

    Class route-map supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param map_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map name", "format": "string"}, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "route-map-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Route map set for input filtering; 'out': Route map set for output filtering; ", "format": "enum"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ipv6/rip/route-map`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "route-map"
        self.a10_url="/axapi/v3/router/ipv6/rip/route-map"
        self.DeviceProxy = ""
        self.map_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Instance(A10BaseClass):
    
    """Class Description::
    Kerberos Authentication Relay.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param kerberos_account: {"description": "Specify the kerberos account name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param name: {"description": "Specify Kerberos authentication relay name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param kerberos_realm: {"description": "Specify the kerberos realm", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param kerberos_kdc_service_group: {"description": "Specify an authentication service group as multiple KDCs", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "kerberos-kdc", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}
    :param timeout: {"description": "Specify timeout for kerberos transport, default is 10 seconds (The timeout, default is 10 seconds)", "format": "number", "default": 10, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param password: {"default": 0, "optional": true, "type": "number", "description": "Specify password of Kerberos password", "format": "flag"}
    :param kerberos_kdc: {"description": "Specify the kerberos kdc ip or host name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "kerberos-kdc-service-group", "type": "string"}
    :param port: {"description": "Specify The KDC port, default is 88", "format": "number", "default": 88, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param secret_string: {"description": "The kerberos client password", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/kerberos/instance/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/relay/kerberos/instance/{name}"
        self.DeviceProxy = ""
        self.kerberos_account = ""
        self.name = ""
        self.encrypted = ""
        self.kerberos_realm = ""
        self.kerberos_kdc_service_group = ""
        self.timeout = ""
        self.password = ""
        self.kerberos_kdc = ""
        self.port = ""
        self.secret_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DistributeInternalList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param area_num: {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param area_ipv4: {"default": "255.255.255.255", "type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}
    :param cost: {"description": "Cost", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}
    :param type: {"enum": ["lw4o6", "nat64", "floating-ip", "ip-nat", "ip-nat-list", "vip", "vip-only-flagged"], "type": "string", "description": "'lw4o6': LW4O6 Prefix; 'nat64': NAT64 Prefix; 'floating-ip': Floating IP; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'vip': Virtual IP (VIP); 'vip-only-flagged': Selected Virtual IP (VIP); ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distribute-internal-list"
        self.DeviceProxy = ""
        self.area_num = ""
        self.area_ipv4 = ""
        self.cost = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ve-cfg"
        self.DeviceProxy = ""
        self.ve = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrunkCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk-cfg"
        self.DeviceProxy = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LoopbackCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "loopback-cfg"
        self.DeviceProxy = ""
        self.loopback = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EthCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "eth-cfg"
        self.DeviceProxy = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PassiveInterface(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}}}]}
    :param trunk_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}}}]}
    :param loopback_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}}}]}
    :param eth_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "passive-interface"
        self.DeviceProxy = ""
        self.ve_cfg = []
        self.trunk_cfg = []
        self.loopback_cfg = []
        self.eth_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Exp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param max_delay: {"description": "Maximum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param min_delay: {"description": "Minimum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "exp"
        self.DeviceProxy = ""
        self.max_delay = ""
        self.min_delay = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Spf(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "spf"
        self.DeviceProxy = ""
        self.exp = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Timers(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "timers"
        self.DeviceProxy = ""
        self.spf = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ospf(A10BaseClass):
    
    """Class Description::
    Open Shortest Path First (OSPFv3).

    Class ospf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param default_metric: {"description": "Set metric of redistributed routes (Default metric)", "format": "number", "default": 20, "optional": true, "maximum": 16777214, "minimum": 1, "type": "number"}
    :param abr_type_option: {"description": "'cisco': Alternative ABR, Cisco implementation (RFC3509); 'ibm': Alternative ABR, IBM implementation (RFC3509); 'standard': Standard behavior (RFC2328); ", "format": "enum", "default": "cisco", "type": "string", "enum": ["cisco", "ibm", "standard"], "optional": true}
    :param auto_cost_reference_bandwidth: {"description": "Use reference bandwidth method to assign OSPF cost (The reference bandwidth in terms of Mbits per second)", "format": "number", "default": 10000, "optional": true, "maximum": 4294967, "minimum": 1, "type": "number"}
    :param router_id: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "router-id for the OSPF process (OSPFv3 router-id in IPv4 address format)", "format": "ipv4-address"}
    :param distribute_internal_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "area-ipv4": {"default": "255.255.255.255", "type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "cost": {"description": "Cost", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "type": {"enum": ["lw4o6", "nat64", "floating-ip", "ip-nat", "ip-nat-list", "vip", "vip-only-flagged"], "type": "string", "description": "'lw4o6': LW4O6 Prefix; 'nat64': NAT64 Prefix; 'floating-ip': Floating IP; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'vip': Virtual IP (VIP); 'vip-only-flagged': Selected Virtual IP (VIP); ", "format": "enum"}, "optional": true}}]}
    :param max_concurrent_dd: {"description": "Maximum number allowed to process DD concurrently (Number of DD process)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param process_id: {"description": "OSPFv3 process tag", "format": "string", "default": "0", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param ha_standby_extra_cost: {"description": "Extra ospf cost when there is any standby HA group (The extra cost value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param bfd_all_interfaces: {"default": 0, "optional": true, "type": "number", "description": "Enable BFD on all interfaces", "format": "flag"}
    :param area_list: {"minItems": 1, "items": {"type": "area"}, "uniqueItems": true, "array": [{"required": ["area-ipv4", "area-num"], "properties": {"area-ipv4": {"optional": false, "type": "string", "description": "OSPFv3 area ID in IP address format", "format": "ipv4-address"}, "virtual-link-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "transmit-delay": {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}, "value": {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}, "retransmit-interval": {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}, "optional": true, "instance-id": {"description": "OSPFv3 instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "no-summary": {"default": 0, "optional": true, "type": "number", "description": "Do not inject inter-area routes into area", "format": "flag"}, "stub": {"default": 0, "optional": true, "type": "number", "description": "Configure OSPFv3 area as stub", "format": "flag"}, "range-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "option": {"enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}, "value": {"type": "string", "description": "Area range for IPv6 prefix", "format": "ipv6-address-plen"}}}]}, "default-cost": {"description": "Set the summary-default cost of a NSSA or stub area (Stub's advertised default summary cost)", "format": "number", "default": 1, "optional": true, "maximum": 16777215, "minimum": 0, "type": "number"}, "area-num": {"description": "OSPFv3 area ID as a decimal value", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 0, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/router/ipv6/ospf/{process-id}/area/{area-ipv4}+{area-num}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ipv6/ospf/{process_id}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "process_id"]

        self.b_key = "ospf"
        self.a10_url="/axapi/v3/router/ipv6/ospf/{process_id}"
        self.DeviceProxy = ""
        self.default_metric = ""
        self.abr_type_option = ""
        self.auto_cost_reference_bandwidth = ""
        self.router_id = ""
        self.distribute_internal_list = []
        self.redistribute = {}
        self.max_concurrent_dd = ""
        self.process_id = ""
        self.passive_interface = {}
        self.timers = {}
        self.ha_standby_extra_cost = ""
        self.bfd_all_interfaces = ""
        self.area_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CmUt(A10BaseClass):
    
    """Class Description::
    CM Unit Test module.

    Class cm-ut supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param post_modify_parent_list: {"minItems": 1, "items": {"type": "post-modify-parent"}, "uniqueItems": true, "array": [{"required": ["k1"], "properties": {"post-modify-child": {"type": "object", "properties": {"f1": {"minimum": 1, "type": "number", "maximum": 32, "format": "number"}}}, "k1": {"minLength": 1, "maxLength": 32, "type": "string", "optional": false, "format": "string"}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/cm-ut/post-modify-parent/{k1}"}
    :param obj_key_2_list: {"minItems": 1, "items": {"type": "obj-key-2"}, "uniqueItems": true, "array": [{"required": ["k1", "k2"], "properties": {"k2": {"minLength": 1, "maxLength": 32, "type": "string", "optional": false, "format": "string"}, "k1": {"optional": false, "minimum": 1, "type": "number", "maximum": 32, "format": "number"}, "d1": {"optional": true, "type": "string", "description": "some data", "format": "ipv4-address"}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/cm-ut/obj-key-2/{k1}+{k2}"}
    :param obj_key_1_list: {"minItems": 1, "items": {"type": "obj-key-1"}, "uniqueItems": true, "array": [{"required": ["k1", "k2"], "properties": {"k2": {"optional": false, "minimum": 1, "type": "number", "maximum": 32, "format": "number"}, "k1": {"minLength": 1, "maxLength": 32, "type": "string", "optional": false, "format": "string"}, "d1": {"description": "some data", "format": "string", "minLength": 1, "optional": true, "maxLength": 64, "type": "string"}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/cm-ut/obj-key-1/{k1}+{k2}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cm-ut`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "cm-ut"
        self.a10_url="/axapi/v3/cm-ut"
        self.DeviceProxy = ""
        self.list_entry_1 = {}
        self.list_entry_2 = {}
        self.post_modify_parent_list = []
        self.list_enum_1 = {}
        self.obj_key_2_list = []
        self.obj_key_1_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Persist(A10BaseClass):
    
    """Class Description::
    Persistence.

    Class persist supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param destination_ip_list: {"minItems": 1, "items": {"type": "destination-ip"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"netmask6": {"description": "IPV6 subnet mask", "format": "number", "default": 128, "optional": true, "maximum": 128, "minimum": 1, "type": "number"}, "scan-all-members": {"default": 0, "optional": true, "type": "number", "description": "Persist with SCAN of all members", "format": "flag"}, "name": {"description": "Destination IP persistence template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "dont-honor-conn-rules": {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}, "netmask": {"default": "255.255.255.255", "optional": true, "type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}, "server": {"description": "Persist to the same server, default is port", "format": "flag", "default": 0, "optional": true, "not": "service-group", "type": "number"}, "service-group": {"description": "Persist within the same service group", "format": "flag", "default": 0, "optional": true, "not": "server", "type": "number"}, "timeout": {"description": "Persistence timeout (in minutes)", "format": "number", "default": 5, "optional": true, "maximum": 2000, "minimum": 1, "type": "number"}, "hash-persist": {"default": 0, "optional": true, "type": "number", "description": "Use hash value of destination IP address", "format": "flag"}, "match-type": {"default": 0, "optional": true, "type": "number", "description": "Persistence type", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/persist/destination-ip/{name}"}
    :param source_ip_list: {"minItems": 1, "items": {"type": "source-ip"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"scan-all-members": {"default": 0, "optional": true, "type": "number", "description": "Persist with SCAN of all members", "format": "flag"}, "netmask6": {"description": "IPV6 subnet mask", "format": "number", "default": 128, "optional": true, "maximum": 128, "minimum": 1, "type": "number"}, "incl-dst-ip": {"default": 0, "optional": true, "type": "number", "description": "Include destination IP on the persist", "format": "flag"}, "name": {"description": "Source IP persistence template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "dont-honor-conn-rules": {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}, "service-group": {"description": "Persist within the same service group", "format": "flag", "default": 0, "optional": true, "not": "server", "type": "number"}, "server": {"description": "Persist to the same server, default is port", "format": "flag", "default": 0, "optional": true, "not": "service-group", "type": "number"}, "incl-sport": {"default": 0, "optional": true, "type": "number", "description": "Include source port on the persist", "format": "flag"}, "netmask": {"default": "255.255.255.255", "optional": true, "type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}, "timeout": {"description": "Persistence timeout (in minutes)", "format": "number", "default": 5, "optional": true, "maximum": 2000, "minimum": 1, "type": "number"}, "hash-persist": {"default": 0, "optional": true, "type": "number", "description": "Use hash value of source IP address", "format": "flag"}, "enforce-higher-priority": {"default": 0, "optional": true, "type": "number", "description": "Enforce to use high priority node if available", "format": "flag"}, "match-type": {"default": 0, "optional": true, "type": "number", "description": "Persistence type", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/persist/source-ip/{name}"}
    :param cookie_list: {"minItems": 1, "items": {"type": "cookie"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"domain": {"description": "Set cookie domain", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "secure": {"default": 0, "optional": true, "type": "number", "description": "Enable secure attribute", "format": "flag"}, "cookie-name": {"description": "Set cookie name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "dont-honor-conn-rules": {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}, "server": {"description": "Persist to the same server, default is port", "format": "flag", "default": 0, "optional": true, "not": "service-group", "type": "number"}, "server-service-group": {"default": 0, "optional": true, "type": "number", "description": "Persist to the same server and within the same service group", "format": "flag"}, "service-group": {"description": "Persist within the same service group", "format": "flag", "default": 0, "optional": true, "not": "server", "type": "number"}, "expire": {"description": "Set cookie expiration time (Expiration in seconds)", "format": "number", "default": 0, "optional": true, "maximum": 31536000, "minimum": 0, "type": "number"}, "match-type": {"default": 0, "optional": true, "type": "number", "description": "Persist for server, default is port", "format": "flag"}, "path": {"description": "Set cookie path (Cookie path, default is \"/\")", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "pass-thru": {"default": 0, "optional": true, "type": "number", "description": "Pass thru mode - Server sends the persist cookie", "format": "flag"}, "scan-all-members": {"default": 0, "optional": true, "type": "number", "description": "Persist within the same server SCAN", "format": "flag"}, "insert-always": {"default": 0, "optional": true, "type": "number", "description": "Insert persist cookie to every reponse", "format": "flag"}, "httponly": {"default": 0, "optional": true, "type": "number", "description": "Enable HttpOnly attribute", "format": "flag"}, "name": {"description": "Cookie persistence (Cookie persistence template name)", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/persist/cookie/{name}"}
    :param ssl_sid_list: {"minItems": 1, "items": {"type": "ssl-sid"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"dont-honor-conn-rules": {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}, "name": {"description": "SSL session ID persistence template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "timeout": {"description": "Persistence timeout (in minutes)", "format": "number", "type": "number", "maximum": 2000, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/persist/ssl-sid/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/persist`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "persist"
        self.a10_url="/axapi/v3/slb/template/persist"
        self.DeviceProxy = ""
        self.destination_ip_list = []
        self.source_ip_list = []
        self.cookie_list = []
        self.ssl_sid_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ospf(A10BaseClass):
    
    """Class Description::
    Enable OSPFv2 traps.

    Class ospf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ospfLsdbOverflow: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfLsdbOverflow traps", "format": "flag"}
    :param ospfVirtIfRxBadPacket: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfVirtIfRxBadPacket traps", "format": "flag"}
    :param ospfNbrStateChange: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfNbrStateChange traps", "format": "flag"}
    :param ospfIfStateChange: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfIfStateChange traps", "format": "flag"}
    :param ospfVirtNbrStateChange: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfVirtNbrStateChange traps", "format": "flag"}
    :param ospfLsdbApproachingOverflow: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfLsdbApproachingOverflow traps", "format": "flag"}
    :param ospfIfAuthFailure: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfIfAuthFailure traps", "format": "flag"}
    :param ospfVirtIfAuthFailure: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfVirtIfAuthFailure traps", "format": "flag"}
    :param ospfVirtIfConfigError: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfVirtIfConfigError traps", "format": "flag"}
    :param ospfIfConfigError: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfIfConfigError traps", "format": "flag"}
    :param ospfTxRetransmit: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfTxRetransmit traps", "format": "flag"}
    :param ospfVirtIfStateChange: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfVirtIfStateChange traps", "format": "flag"}
    :param ospfVirtIfTxRetransmit: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfVirtIfTxRetransmit traps", "format": "flag"}
    :param ospfMaxAgeLsa: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfMaxAgeLsa traps", "format": "flag"}
    :param ospfIfRxBadPacket: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfIfRxBadPacket traps", "format": "flag"}
    :param ospfOriginateLsa: {"default": 0, "optional": true, "type": "number", "description": "Enable ospfOriginateLsa traps", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/routing/ospf`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ospf"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/routing/ospf"
        self.DeviceProxy = ""
        self.ospfLsdbOverflow = ""
        self.ospfVirtIfRxBadPacket = ""
        self.ospfNbrStateChange = ""
        self.ospfIfStateChange = ""
        self.ospfVirtNbrStateChange = ""
        self.ospfLsdbApproachingOverflow = ""
        self.ospfIfAuthFailure = ""
        self.ospfVirtIfAuthFailure = ""
        self.ospfVirtIfConfigError = ""
        self.ospfIfConfigError = ""
        self.ospfTxRetransmit = ""
        self.ospfVirtIfStateChange = ""
        self.ospfVirtIfTxRetransmit = ""
        self.ospfMaxAgeLsa = ""
        self.ospfIfRxBadPacket = ""
        self.ospfOriginateLsa = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


